@@ -543,7 +543,11 @@ void MainWindow::convertImage(const QString &source)
 
         bool useFractionals = importImageDlg->useFractionals();
 
+#if MagickLibVersion < 0x700
         bool hasTransparency = convertedImage.matte();
+#else
+        bool hasTransparency = convertedImage.alpha();
+#endif
         bool ignoreColor = importImageDlg->ignoreColor();
         Magick::Color ignoreColorValue = importImageDlg->ignoreColorValue();
 
@@ -564,8 +568,6 @@ void MainWindow::convertImage(const QString &source)
         QProgressDialog progress(i18n("Converting to stitches"), i18n("Cancel"), 0, pixelCount, this);
         progress.setWindowModality(Qt::WindowModal);
 
-        const Magick::PixelPacket *pixels = convertedImage.getConstPixels(0, 0, imageWidth, imageHeight);
-
         for (int dy = 0 ; dy < imageHeight ; dy++) {
             progress.setValue(dy * imageWidth);
             QApplication::processEvents();
@@ -577,8 +579,8 @@ void MainWindow::convertImage(const QString &source)
             }
 
             for (int dx = 0 ; dx < imageWidth ; dx++) {
-                Magick::ColorRGB rgb = Magick::Color(*pixels++);
-
+                Magick::ColorRGB rgb = convertedImage.pixelColor(dx, dy);
+                
                 if (hasTransparency && (rgb.alpha() == 1)) {
                     // ignore this pixel as it is transparent
                 } else {
@@ -916,14 +918,12 @@ void MainWindow::preferences()
     }
 
     KConfigDialog *dialog = new KConfigDialog(this, QStringLiteral("preferences"), Configuration::self());
-//    dialog->setHelp("ConfigurationDialog");
     dialog->setFaceType(KPageDialog::List);
 
     dialog->addPage(new EditorConfigPage(0, QStringLiteral("EditorConfigPage")), i18nc("The Editor config page", "Editor"), QStringLiteral("preferences-desktop"));
     dialog->addPage(new PatternConfigPage(0, QStringLiteral("PatternConfigPage")), i18n("Pattern"), QStringLiteral("ksnapshot"));
     PaletteConfigPage *paletteConfigPage = new PaletteConfigPage(0, QStringLiteral("PaletteConfigPage"));
     dialog->addPage(paletteConfigPage, i18n("Palette"), QStringLiteral("preferences-desktop-color"));
-    connect(dialog, SIGNAL(defaultClicked()), paletteConfigPage, SLOT(defaultClicked()));
     dialog->addPage(new ImportConfigPage(0, QStringLiteral("ImportConfigPage")), i18n("Import"), QStringLiteral("insert-image"));
     dialog->addPage(new LibraryConfigPage(0, QStringLiteral("LibraryConfigPage")), i18n("Library"), QStringLiteral("accessories-dictionary"));
     dialog->addPage(new PrinterConfigPage(0, QStringLiteral("PrinterConfigPage")), i18n("Printer Configuration"), QStringLiteral("preferences-desktop-printer"));
@@ -997,8 +997,8 @@ void MainWindow::loadSettings()
         actions->action(QStringLiteral("formatScalesAsInches"))->trigger();
         break;
 
-    case Configuration::EnumEditor_FormatScalesAs::CM:
-        actions->action(QStringLiteral("formatScalesAsCM"))->trigger();
+    case Configuration::EnumEditor_FormatScalesAs::Centimeters:
+        actions->action(QStringLiteral("formatScalesAsCentimeters"))->trigger();
         break;
 
     default:
@@ -1488,10 +1488,10 @@ void MainWindow::setupActions()
     actionGroup->addAction(action);
 
     action = new QAction(this);
-    action->setText(i18n("CM"));
+    action->setText(i18n("Centimeters"));
     action->setCheckable(true);
-    connect(action, SIGNAL(triggered()), m_editor, SLOT(formatScalesAsCM()));
-    actions->addAction(QStringLiteral("formatScalesAsCM"), action);
+    connect(action, SIGNAL(triggered()), m_editor, SLOT(formatScalesAsCentimeters()));
+    actions->addAction(QStringLiteral("formatScalesAsCentimeters"), action);
     actionGroup->addAction(action);
 
     action = new QAction(this);
@@ -1642,11 +1642,11 @@ void MainWindow::setupActions()
     actions->addAction(QStringLiteral("renderBackgroundImages"), action);
 
     m_horizontalScale->addAction(actions->action(QStringLiteral("formatScalesAsStitches")));
-    m_horizontalScale->addAction(actions->action(QStringLiteral("formatScalesAsCM")));
+    m_horizontalScale->addAction(actions->action(QStringLiteral("formatScalesAsCentimeters")));
     m_horizontalScale->addAction(actions->action(QStringLiteral("formatScalesAsInches")));
 
     m_verticalScale->addAction(actions->action(QStringLiteral("formatScalesAsStitches")));
-    m_verticalScale->addAction(actions->action(QStringLiteral("formatScalesAsCM")));
+    m_verticalScale->addAction(actions->action(QStringLiteral("formatScalesAsCentimeters")));
     m_verticalScale->addAction(actions->action(QStringLiteral("formatScalesAsInches")));
 
     setupGUI(KXmlGuiWindow::Default, QStringLiteral("kxstitchui.rc"));
